package ueb6;

import java.awt.Point;

public class Packstation {

	/**
	 * Zweidimensionales Array zur Speicherung von Paketen, wobei jede Position 
	 * im Array ein Fach in der Packstation repräsentiert.
	 */
	public Paket[][] station;

	//Standard-Konstruktor
	public Packstation() {
		station = new Paket[5][4];
	}
	
	/**
	 * Dieser Konstruktor legt eine Packstation mit benutzerdefinierter Größe an.
	 * @param breite: Die Anzahl an Fächern in der Breite der Packstation.
	 * @param hoehe: Die Anzahl an Fächern in der Höhe der Packstation.
	 */
	public Packstation(int breite, int hoehe) {
		if (breite <= 0 || hoehe <= 0) {
			throw new IllegalArgumentException("Breite und Höhe müssen größer als 0 sein.");
		}
		station = new Paket[breite][hoehe];
	}


	/**
	 * Legt ein Paket an einer freien Stelle in der Packstation ab und gibt die 
	Position zurück.
	 * @param paket: Das abzulegende Paket.
	 * @return Ein Point-Objekt, das die Position (Spalte, Reihe) enthält, an der das 
	Paket abgelegt wurde. Die kleinste Position für ein Paket ist x=0,y=0. 
	 * @throws IllegalStateException Wenn kein Platz mehr in der Packstation ist.
	 */
	public Point legePaketAb(Paket paket) throws IllegalStateException {
		for (int i=0; i < station.length; i++) {
			for(int j=0; j < station[i].length; j++) {
				if (station[i][j] == null) {
					station[i][j] = paket;
					return new Point(i, j);
				}
			}
		}
		throw new IllegalStateException("Kein Platz mehr in der Packstation.");
	}

	/**
	 * Zählt die Anzahl der freien Boxen in der Packstation.
	 * @return Die Anzahl der freien Boxen als ganze Zahl.
	 */
	public int zaehleFreieBoxen() {
		int count = 0;

		for(int i = 0; i < station.length; i++) {
			for(int j = 0; j < station[0].length; j++) {
				if (station[i][j] == null)
					count++;
			}
		}
		return count;   
	}


	/**
	 * Liefert Informationen über den Empfänger und die Adresse des Pakets, das an der 
	  angegebenen Position abgelegt ist,
	 * sofern die Box belegt ist. Andernfalls wird die Information zurückgegeben, dass 
	  die Box leer ist.
	 * Falls die angegebene Box nicht existiert, wird eine IllegalArgumentException 
	  Exception geworfen.
	 * @param spalte: Die Spalte der Box in der Packstation (beginnend bei 0).
	 * @param reihe: Die Reihe der Box in der Packstation (beginnend bei 0) .
	 * @return Ein String mit Informationen über den Empfänger und die Adresse des 
	  Pakets oder die Nachricht "Die Box ist leer".
	 * @throws IllegalArgumentException Wenn die angegebene Box nicht existiert.
	 */
	public String informationZumBoxenplatz(int spalte, int reihe) throws IllegalArgumentException {
		if (spalte >= station.length || reihe >= station[spalte].length)
			throw new IllegalArgumentException("Die angegebene Box existiert nicht.");
		else if (station[spalte][reihe] == null)
			return "Die Box ist leer.";
		else
			return station[spalte][reihe].toString();
	}
	
	/**
	 * Gibt die Packstation formatiert aus bei Werten von 0-9
	 */
	public void printStation() {
		System.out.print(" ");
		for (int i=0; i < station[0].length; i++)
			System.out.print("---------- ");
		System.out.print("\n");
			
		for (int j = station.length-1; j >= 0; j--) {
			System.out.print("|");
			for (int i = 0; i < station[j].length; i++) {
				System.out.printf("  [%d][%d]  |", j, i);
			}
			System.out.print("\n");
			System.out.print(" ");
			for (int i=0; i < station[0].length; i++)
				System.out.print("---------- ");
			System.out.print("\n");
		}
		
	}
}
